@@ -113,7 +113,7 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Incidenc
 #if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto job = KIO::stat(QUrl(a.uri()), KIO::StatJob::SourceSide, 0);
 #else
-        auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatDetail::Basic);
+        auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatBasic);
 #endif
 
         KJobWidgets::setWindow(job, d->mParent);
